@@ -4,9 +4,8 @@ use Class::Load ':all';
 use Data::Dumper;
 use Data::Printer;
 use Try::Tiny;
-use v5.10;
 
-our $VERSION     = '0.07';
+our $VERSION     = '0.08';
 
 my $CUSTOMIZABLES = {
 #   reader      => 'HTML::Robot::Scrapper::Reader',
@@ -124,22 +123,23 @@ sub _load_custom_class {
     try {
         $base_class = load_class( $base_class );
     } catch {
-        say "Could not load base_class: " . $base_class;
+        print "Could not load base_class: " . $base_class . "\n";
     };
-#say $base_class;
 
     #load custom engine
     try {
         $engine_class = load_class( $engine_class );
     } catch {
-        $engine_class = load_class( $options->{ $option }->{ class } );
+        warn "ERROR/WARNING Could not load class $engine_class. error: $_";
+        warn "Trying to load:" . $options->{ $option }->{ class };
+        try {
+            $engine_class = load_class( $options->{ $option }->{ class } );
+            return 1;
+        } catch {
+            warn "Fatal error: Could not load class $engine_class. error: $_";
+        };
     };
-#say $engine_class;
-#say $option;
     my $args = $options->{$option}->{args}||{};
-    say $option;
-    say p $args;
-    say '-----------------------';
     $options->{$option} = $base_class->new(
         engine => $engine_class->new( $args ),
         ( exists $options->{$option}->{args}->{is_active}) ?
@@ -181,8 +181,8 @@ sub start {
     while ( my $item = $self->queue->queue_get_item ) {
         $self->benchmark->method_start('finish_in');
 
-        say '--[ '.$counter++.' ]------------------------------------------------------------------------------';
-        say ' url: '. $item->{ url } if exists $item->{ url };
+        print '--[ '.$counter++.' ]------------------------------------------------------------------------------'."\n";
+        print ' url: '. $item->{ url }."\n" if exists $item->{ url };
         my $method = $item->{ method };
         my $res = $self->useragent->visit($item);
 
@@ -203,7 +203,9 @@ sub start {
         $self->benchmark->method_start( $method );
         try {
           $self->reader->$method( );
-        } catch {};
+        } catch {
+          warn "ERROR on reader->$method: $_";
+        };
         $self->benchmark->method_finish( $method );
 
         $self->benchmark->method_finish('finish_in', 'Total: ' );
@@ -217,22 +219,30 @@ HTML::Robot::Scrapper - Your robot to parse webpages
 
 =head1 SYNOPSIS
 
-First off, the site for this bot answers with content type text/plain and by default
+See a working example under the module: WWW::Tabela::Fipe ( search on cpan ). 
+
+The class
 
     HTML::Robot::Scrapper::Parser::Default
 
-handles only text/html and text/xml 
+handles only text/html and text/xml by default
 
 So i need to add an extra option for text/plain and tell it to use 
 
 the same method that already parses text/html, here is an example:
 
-* im using the original as base class for this: 
+* im using the code from the original as base class for this: 
 
     HTML::Robot::Scrapper::Parser::Default
 
 Here i will redefine that class and tell my $robot to favor it
 
+    ...
+    parser => {class => 'WWW::Tabela::Fipe::Parser'},
+    ...
+
+See below:
+
     package WWW::Tabela::Fipe::Parser;
     use Moose;
 
@@ -318,7 +328,64 @@ Here i will redefine that class and tell my $robot to favor it
 
 =head1 DESCRIPTION
 
-This cralwer has been created to be extensible.
+This cralwer has been created to be extensible. Scalable with redis queue.
+
+The main idea is: i need a queue of urls to be crawled, it can be an array living during 
+
+my instance (not scalable)... or it can be a Redis queue ( scallable ), being acessed by 
+
+many HTML::Robot::Scrapper instances.
+
+Each request inserted into the queue is suposed to be independent. So this thing can scale. I mean,
+
+Supose i need to create an object using stuff from page1, page2 and page3... that will be 3 requests
+
+so, the first request will access page1 and collect data into $colleted_data, then, i will append another
+
+request for page2 with $collected_data from page 1. So the request for page2 will collect some more data 
+
+and merge with $collected_data from page1 generating $collected_data_from_page1_and_page2, and then i will insert
+
+a new request into my queue for page3 that will collect data and merge with $collected_data_from_page1_and_page2
+
+and create the final object: $collected_data_complete. 
+
+
+Basicly, you need to create a 
+
+    - reader: to read/parse your webpages and 
+
+and a
+        
+    - writer: to save data you reader collected.
+
+You 'might' need to add other content types also, creating your custom class based on:
+
+    HTML::Robot::Scrapper::Parser::Default
+
+See it and you will understand.. by default it handles: 
+    
+    - text/html
+    - text/xml
+
+=head1 READER ( you create this )
+
+Reader: Its where the parsing logic for a specific site lives.
+
+You customize the reader telling it where the nodes are, etc..
+
+The reader class is where you create your parser.
+
+=head2 WRITER ( you create this )
+
+Writer: Its the class that will save the data the reader collects.
+
+ie: You can create a method "save" that receives an object and simply writes into your DB.
+
+Or you can make it write into DB + elastic search .. etc.. whatever you want
+
+
+=head1 CONTENT TYPES AND PARSING METHODS ( you might need to extend this )
 
 For example, after making a request call ( HTML::Robot::Scrapper::UserAgent::Default ) 
 
@@ -339,9 +406,9 @@ by default the class that handles that is:
                 {
                     parse_method => 'parse_xpath',
                     description => q{
-    The method above 'parse_xpath' is inside class:
-    HTML::Robot::Scrapper::Parser::HTML::TreeBuilder::XPath
-    },
+                        The method above 'parse_xpath' is inside class:
+                        HTML::Robot::Scrapper::Parser::HTML::TreeBuilder::XPath
+                    },
                 }
             ],
             'text/xml' => [
@@ -354,6 +421,12 @@ by default the class that handles that is:
 
     1;
 
+WWW::Tabela::FIPE has a custom Parser class and you can see it as an example. 
+
+If you need to download images, you will need to create a custom parser class adding 'image/png' as content type for example.
+
+=head1 QUEUE OF REQUESTS
+
 Another example is the Queue system, it has an api: HTML::Robot::Scrapper::Queue::Base and by default
 
 uses: HTML::Robot::Scrapper::Queue::Array which works fine for 1 local instance. However, lets say i want a REDIS queue, so i could
